@@ -13,7 +13,7 @@ from dataclasses import dataclass
 from typing import List, Optional, Tuple, Union
 
 from anchorpoint.textsequences import TextPassage, TextSequence
-from anchorpoint.utils._helper import _is_iterable_non_string
+from anchorpoint.utils._helper import _is_iterable_non_string, InfiniteValue
 from anchorpoint.utils.ranges import Range, RangeSet
 from marshmallow import ValidationError
 
@@ -266,6 +266,27 @@ class TextPositionSelector(Range):
             include_end=self.include_end,
         )
 
+    @classmethod
+    def from_text(
+        cls,
+        text: str,
+        start: Union[int, str] = 0,
+        end: Optional[Union[int, str]] = None,
+    ) -> TextPositionSelector:
+        if isinstance(start, str):
+            start_index = text.find(start)
+            if start_index == -1:
+                raise TextSelectionError(f"String {start} not found in text.")
+            start = start_index
+
+        if isinstance(end, str):
+            end_index = text.find(end)
+            if end_index == -1:
+                raise TextSelectionError(f"String {end} not found in text.")
+            end = end_index + len(end)
+
+        return cls(start=start, end=end)
+
     @property
     def real_start(self) -> int:
         """Start value following Python convention of including first character."""
@@ -384,7 +405,11 @@ class TextPositionSelector(Range):
 
     def validate(self, text: str) -> None:
         """Verify that selector's text positions exist in text."""
-        if self.end and self.end > len(text):
+        if (
+            self.end
+            and not isinstance(self.end, InfiniteValue)
+            and self.end > len(text)
+        ):
             raise IndexError(
                 f'Text "{text}" is too short to include '
                 + f"the interval ({self.start}, {self.end})"
@@ -393,6 +418,12 @@ class TextPositionSelector(Range):
 
 
 class TextPositionSet(RangeSet):
+    """
+    A set of TextPositionSelectors.
+
+    Implements the interface of Python :py:class:`set`\s.
+    """
+
     def __init__(self, *args):
         """
         Constructs a new TextPositionSet containing the given sub-ranges.
